# FTSA-TJPB

Bem-vindo(a) ao ***Framework* de Testes de Sistema Automatizados** (testes de aceitação do usuário nas interfaces *web*, *mobile* e *serviços*) do Tribunal de Justiça do Estado da Paraíba (TJ-PB), ou simplesmente ***FTSA-TJPB***.

Nesta página nós disponibilizamos uma breve documentação para sua instalação e uso. 

Este projeto é composto de três módulos principais (e serão detalhados adiante):

* **CLI:** ou módulo *cliente*, disponibiliza um conjunto de comandos (terminal/console) que auxiliam na criação inicial de projetos estruturados e na execução de comandos no terminal de forma simplificada.
* **CORE:** provê as classes da [*API Robot*](http://robotframework.org/) assim como uma série de palavras-chave personalizadas com funcionalidades úteis para o contexto de automação no TJ-PB. 
* **Central:** (*indisponível*) aplicação *web* para o gerenciamento de projetos/produtos, especificação de *features BDD (Behaviour-Driven Development)*, execução de suítes de testes manuais e automático (por versão e *baseline*), além da disponibilização de relatórios com as principais métricas de testes utilizadas.

# Documentação do FTSA-TJPB-CLI

(*indisponível*) 

## Instalação

(*indisponível*)

## Módulo CLI

(*indisponível*)

# Contact

* **Autor:** Carlos Diego Quirino Lima
* **Emails:** 
    * Pessoal: [diegoquirino@gmail.com](mailto:diegoquirino@gmail.com)
    * Profissional: [diego.quirino@tjpb.jus.br](mailto:diego.quirino@tjpb.jus.br)